Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(98)

Unified Diff: generated/googleapis/lib/bigquery/v2.dart

Issue 1296863002: Api-roll 22: 2015-08-17 (Closed) Base URL: git@github.com:dart-lang/googleapis.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « generated/googleapis/README.md ('k') | generated/googleapis/lib/cloudbilling/v1.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: generated/googleapis/lib/bigquery/v2.dart
diff --git a/generated/googleapis/lib/bigquery/v2.dart b/generated/googleapis/lib/bigquery/v2.dart
index 0b506e0145609817463e0296ce7edffc5e825259..4c8534042b3a2f0cb9c86ca484e7ae1beee76f76 100644
--- a/generated/googleapis/lib/bigquery/v2.dart
+++ b/generated/googleapis/lib/bigquery/v2.dart
@@ -1832,6 +1832,12 @@ class ExternalDataConfiguration {
class GetQueryResultsResponse {
/** Whether the query result was fetched from the query cache. */
core.bool cacheHit;
+ /**
+ * [Output-only] All errors and warnings encountered during the running of the
+ * job. Errors here do not necessarily mean that the job has completed or was
+ * unsuccessful.
+ */
+ core.List<ErrorProto> errors;
/** A hash of this response. */
core.String etag;
/**
@@ -1879,6 +1885,9 @@ class GetQueryResultsResponse {
if (_json.containsKey("cacheHit")) {
cacheHit = _json["cacheHit"];
}
+ if (_json.containsKey("errors")) {
+ errors = _json["errors"].map((value) => new ErrorProto.fromJson(value)).toList();
+ }
if (_json.containsKey("etag")) {
etag = _json["etag"];
}
@@ -1913,6 +1922,9 @@ class GetQueryResultsResponse {
if (cacheHit != null) {
_json["cacheHit"] = cacheHit;
}
+ if (errors != null) {
+ _json["errors"] = errors.map((value) => (value).toJson()).toList();
+ }
if (etag != null) {
_json["etag"] = etag;
}
@@ -3421,6 +3433,12 @@ class QueryResponse {
/** Whether the query result was fetched from the query cache. */
core.bool cacheHit;
/**
+ * [Output-only] All errors and warnings encountered during the running of the
+ * job. Errors here do not necessarily mean that the job has completed or was
+ * unsuccessful.
+ */
+ core.List<ErrorProto> errors;
+ /**
* Whether the query has completed or not. If rows or totalRows are present,
* this will always be true. If this is false, totalRows will not be
* available.
@@ -3467,6 +3485,9 @@ class QueryResponse {
if (_json.containsKey("cacheHit")) {
cacheHit = _json["cacheHit"];
}
+ if (_json.containsKey("errors")) {
+ errors = _json["errors"].map((value) => new ErrorProto.fromJson(value)).toList();
+ }
if (_json.containsKey("jobComplete")) {
jobComplete = _json["jobComplete"];
}
@@ -3498,6 +3519,9 @@ class QueryResponse {
if (cacheHit != null) {
_json["cacheHit"] = cacheHit;
}
+ if (errors != null) {
+ _json["errors"] = errors.map((value) => (value).toJson()).toList();
+ }
if (jobComplete != null) {
_json["jobComplete"] = jobComplete;
}
@@ -3526,6 +3550,53 @@ class QueryResponse {
}
}
+class Streamingbuffer {
+ /**
+ * [Output-only] A lower-bound estimate of the number of bytes currently in
+ * the streaming buffer.
+ */
+ core.String estimatedBytes;
+ /**
+ * [Output-only] A lower-bound estimate of the number of rows currently in the
+ * streaming buffer.
+ */
+ core.String estimatedRows;
+ /**
+ * [Output-only] Contains the timestamp of the oldest entry in the streaming
+ * buffer, in milliseconds since the epoch, if the streaming buffer is
+ * available.
+ */
+ core.String oldestEntryTime;
+
+ Streamingbuffer();
+
+ Streamingbuffer.fromJson(core.Map _json) {
+ if (_json.containsKey("estimatedBytes")) {
+ estimatedBytes = _json["estimatedBytes"];
+ }
+ if (_json.containsKey("estimatedRows")) {
+ estimatedRows = _json["estimatedRows"];
+ }
+ if (_json.containsKey("oldestEntryTime")) {
+ oldestEntryTime = _json["oldestEntryTime"];
+ }
+ }
+
+ core.Map toJson() {
+ var _json = new core.Map();
+ if (estimatedBytes != null) {
+ _json["estimatedBytes"] = estimatedBytes;
+ }
+ if (estimatedRows != null) {
+ _json["estimatedRows"] = estimatedRows;
+ }
+ if (oldestEntryTime != null) {
+ _json["oldestEntryTime"] = oldestEntryTime;
+ }
+ return _json;
+ }
+}
+
class Table {
/**
* [Output-only] The time when this table was created, in milliseconds since
@@ -3565,19 +3636,25 @@ class Table {
*/
core.String location;
/**
* [Output-only] The size of the table in bytes. This property is unavailable
* for tables that are actively receiving streaming inserts.
*/
core.String numBytes;
/**
* [Output-only] The number of rows of data in this table. This property is
* unavailable for tables that are actively receiving streaming inserts.
*/
core.String numRows;
/** [Optional] Describes the schema of this table. */
TableSchema schema;
/** [Output-only] A URL that can be used to access this resource again. */
core.String selfLink;
+ /**
+ * [Output-only] Contains information regarding this table's streaming buffer,
+ * if one is present. This field will be absent if the table is not being
+ * streamed to or if there is no data in the streaming buffer.
+ */
+ Streamingbuffer streamingBuffer;
/** [Required] Reference describing the ID of this table. */
TableReference tableReference;
/**
@@ -3634,6 +3711,9 @@ class Table {
if (_json.containsKey("selfLink")) {
selfLink = _json["selfLink"];
}
+ if (_json.containsKey("streamingBuffer")) {
+ streamingBuffer = new Streamingbuffer.fromJson(_json["streamingBuffer"]);
+ }
if (_json.containsKey("tableReference")) {
tableReference = new TableReference.fromJson(_json["tableReference"]);
}
@@ -3689,6 +3769,9 @@ class Table {
if (selfLink != null) {
_json["selfLink"] = selfLink;
}
+ if (streamingBuffer != null) {
+ _json["streamingBuffer"] = (streamingBuffer).toJson();
+ }
if (tableReference != null) {
_json["tableReference"] = (tableReference).toJson();
}
@@ -3565,19 +3636,25 @@ class Table {
core.String location;
/**
- * [Output-only] The size of the table in bytes. This property is unavailable
- * for tables that are actively receiving streaming inserts.
+ * [Output-only] The size of this table in bytes, excluding any data in the
+ * streaming buffer.
*/
core.String numBytes;
@@ -3565,19 +3636,25 @@ class Table {
core.String numBytes;
/**
- * [Output-only] The number of rows of data in this table. This property is
- * unavailable for tables that are actively receiving streaming inserts.
+ * [Output-only] The number of rows of data in this table, excluding any data
+ * in the streaming buffer.
*/
core.String numRows;
« no previous file with comments | « generated/googleapis/README.md ('k') | generated/googleapis/lib/cloudbilling/v1.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698